summaryrefslogtreecommitdiffstats
path: root/src/usr/local/www/interfaces_groups_edit.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/local/www/interfaces_groups_edit.php')
-rw-r--r--src/usr/local/www/interfaces_groups_edit.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/usr/local/www/interfaces_groups_edit.php b/src/usr/local/www/interfaces_groups_edit.php
index d215288..e8bbf4d 100644
--- a/src/usr/local/www/interfaces_groups_edit.php
+++ b/src/usr/local/www/interfaces_groups_edit.php
@@ -116,11 +116,11 @@ if ($_POST) {
}
/*
* Packages (e.g. tinc) creates interface groups, reserve this
* namespace pkg- for them
*/
- if (substr($_POST['ifname'], 0, 4) == 'pkg-') {
- $input_errors[] = gettext("Group name cannot start with pkg-");
+ if (substr($_POST['ifname'], 0, 4) == 'pkg_') {
+ $input_errors[] = gettext("Group name cannot start with pkg_");
}
foreach ($interface_list_disabled as $gif => $gdescr) {
OpenPOWER on IntegriCloud
@@ -116,11 +116,11 @@ if ($_POST) {
}
/*
- * Packages (e.g. tinc) creates interface groups, reserve this
- * namespace pkg- for them
+ * Packages (e.g. tinc) create interface groups, reserve this
+ * namespace pkg_ for them
*/